pub struct Config { /* private fields */ }Expand description
Configuration for DICOM de-identification.
This struct contains all the settings that control how DICOM objects will be de-identified, including UID handling, tag-specific actions, and policies for special tag groups.
Fields
hash_fn- The hash function used for all operations requiring hashinguid_root- TheUidRootto use as prefix when generating new UIDs during de-identificationremove_private_tags- Policy determining whether to keep or remove private DICOM tagsremove_curves- Policy determining whether to keep or remove curve data (groups0x5000-0x50FF)remove_overlays- Policy determining whether to keep or remove overlay data (groups0x6000-0x60FF)tag_actions- Mapping of specific DICOM tags to their corresponding de-identification actions
Implementations
Sourceimpl Config
impl Config
pub fn get_hash_fn(&self) -> HashFn
pub fn get_uid_root(&self) -> &Option<UidRoot>
Sourcepub fn get_action(&self, tag: &Tag) -> &Action
pub fn get_action(&self, tag: &Tag) -> &Action
Returns the appropriate Action to take for a given DICOM tag.
This function determines what action should be taken for a specific tag during de-identification by checking:
- If the tag has an explicit action defined in
tag_actions - Whether the tag should be removed based on the configuration for tag groups (i.e. private tags, curves, overlays)
Priority Rules
- If the tag has an explicit action configured of
Action::Nonebut should be removed based on point 2., returnsAction::Remove - If the tag has any other explicit action configured, returns that action
- If the tag has no explicit action configured but should be removed based on point 2., returns
Action::Remove - If the tag has no explicit action configured and shouldn’t be removed based on point 2., returns
Action::Keep
Arguments
tag- Reference to the DICOM tag to get the action for
Returns
A reference to the appropriate Action to take for the given tag